@@ -49,7 +49,7 @@ from debian.deb822 import Deb822
 from .reformatting import FormattingUnpreservable
 
 
-__version__ = (0, 54)
+__version__ = (0, 55)
 version_string = '.'.join(map(str, __version__))
 SUPPORTED_CERTAINTIES = ['certain', 'confident', 'likely', 'possible', None]
 DEFAULT_MINIMUM_CERTAINTY = 'certain'
@@ -564,7 +564,7 @@ def check_clean_tree(local_tree):
         raise PendingChanges(local_tree)
 
 
-def add_changelog_entry(tree, path, summary):
+def add_changelog_entry(tree, path, summary, qa=False):
     """Add a changelog entry.
 
     Args:
@@ -572,8 +572,11 @@ def add_changelog_entry(tree, path, summary):
       path: Path to the changelog file
       summary: Entry to add
     """
+    args = ["dch", "--no-auto-nmu"]
+    if qa:
+        args.append('--qa')
     p = subprocess.Popen(
-        ["dch", "--no-auto-nmu", summary],
+        args + [summary],
         cwd=tree.abspath(os.path.dirname(os.path.dirname(path))),
         stdin=subprocess.PIPE, stdout=subprocess.PIPE,
         stderr=subprocess.PIPE)
@@ -766,9 +769,9 @@ def run_lintian_fixer(local_tree, fixer, committer=None,
     for tag in result.fixed_lintian_tags:
         description += "\n"
         description += "\n"
-        description += "Fixes lintian: %s\n" % tag
-        description += ("See https://lintian.debian.org/tags/%s.html "
-                        "for more details.\n") % tag
+        description += "Fixes: lintian: %s\n" % tag
+        description += (
+            "See-also: https://lintian.debian.org/tags/%s.html\n" % tag)
 
     if committer is None:
         committer = get_committer(local_tree)
