@@ -41,6 +41,7 @@ from lintian_brush.vcs import (
     plausible_url as plausible_vcs_url,
     sanitize_url as sanitize_vcs_url,
     is_gitlab_site,
+    split_vcs_url,
     )
 from lintian_brush.watch import parse_watch_file
 from urllib.request import urlopen, Request
@@ -57,6 +58,8 @@ class UpstreamDatum(object):
 
     def __init__(self, field, value, certainty=None, origin=None):
         self.field = field
+        if value is None:
+            raise ValueError(field)
         self.value = value
         if certainty not in SUPPORTED_CERTAINTIES:
             raise ValueError(certainty)
@@ -510,14 +513,13 @@ def guess_from_readme(path, trust_package):
 
 
 def guess_from_debian_patch(path, trust_package):
-    with open(path, 'r') as f:
+    with open(path, 'rb') as f:
         for line in f:
-            if line.startswith('Forwarded: '):
-                forwarded = line.split(':', 1)[1].strip()
-                bug_db = bug_database_from_issue_url(forwarded)
+            if line.startswith(b'Forwarded: '):
+                forwarded = line.split(b':', 1)[1].strip()
+                bug_db = bug_database_from_issue_url(forwarded.decode('utf-8'))
                 if bug_db:
                     yield UpstreamDatum('Bug-Database', bug_db, 'possible')
-    return []
 
 
 def guess_from_meta_json(path, trust_package):
@@ -599,7 +601,7 @@ def guess_from_doap(path, trust_package):
             '{http://www.w3.org/1999/02/22-rdf-syntax-ns#}resource')
 
     for child in root:
-        if child.tag == ('{%s}name' % DOAP_NAMESPACE):
+        if child.tag == ('{%s}name' % DOAP_NAMESPACE) and child.text:
             yield UpstreamDatum('Name', child.text, 'certain')
         if child.tag == ('{%s}bug-database' % DOAP_NAMESPACE):
             url = extract_url(child)
@@ -640,6 +642,10 @@ def guess_from_doap(path, trust_package):
                             'Repository-Browse', web_url, 'certain')
 
 
+def is_email_address(value):
+    return '@' in value or ' (at) ' in value
+
+
 def guess_from_configure(path, trust_package=False):
     with open(path, 'rb') as f:
         for line in f:
@@ -661,7 +667,8 @@ def guess_from_configure(path, trust_package=False):
             elif key == b'PACKAGE_BUGREPORT':
                 if value in (b'BUG-REPORT-ADDRESS', ):
                     certainty = 'invalid'
-                elif b'@' in value and not value.endswith(b'gnu.org'):
+                elif (is_email_address(value.decode()) and
+                        not value.endswith(b'gnu.org')):
                     # Downgrade the trustworthiness of this field for most
                     # upstreams if it contains an e-mail address. Most
                     # upstreams seem to just set this to some random address,
@@ -947,6 +954,7 @@ def bug_database_from_issue_url(url):
 
 
 def guess_bug_database_url_from_repo_url(url):
+    url = split_vcs_url(url)[0]
     parsed_url = urlparse(url)
     if parsed_url.netloc == 'github.com':
         path = '/'.join(parsed_url.path.split('/')[:3])
@@ -1025,7 +1033,7 @@ def verify_bug_database_url(url):
 
 def verify_bug_submit_url(url):
     parsed_url = urlparse(url)
-    if parsed_url.netloc == 'gitlab.com' or is_gitlab_site(parsed_url.netloc):
+    if parsed_url.netloc == 'github.com' or is_gitlab_site(parsed_url.netloc):
         path = '/'.join(parsed_url.path.strip('/').split('/')[:-1])
         return verify_bug_database_url(
             urlunparse(parsed_url._replace(path=path)))
@@ -1478,6 +1486,15 @@ def fix_upstream_metadata(upstream_metadata):
         repo.value = url
 
 
+# If we're setting them new, put Name and Contact first
+def upstream_metadata_sort_key(x):
+    (k, v) = x
+    return {
+        'Name': '00-Name',
+        'Contact': '01-Contact',
+        }.get(k, k)
+
+
 def main(argv=None):
     import argparse
     import sys
